@@ -1,6 +1,6 @@
 # (c) 2003-2008 Vlado Keselj http://www.cs.dal.ca/~vlado
 #
-# $Id: Schedule.pm,v 1.25 2008/09/03 11:31:20 vlado Exp $
+# $Id: Schedule.pm,v 1.26 2008/09/03 11:45:33 vlado Exp $
 # <? read_starfish_conf(); !>
  
 package Calendar::Schedule;
@@ -17,12 +17,12 @@ our @EXPORT = qw(new);
 
 #<?echo "our \$VERSION = '$Meta->{version}';"!>
 #+
-our $VERSION = '0.05';
+our $VERSION = '1.01';
 #-
 
 use vars qw($Version $Revision);
 $Version = $VERSION;
-($Revision = substr(q$Revision: 1.25 $, 10)) =~ s/\s+$//;
+($Revision = substr(q$Revision: 1.26 $, 10)) =~ s/\s+$//;
 
 # non-exported package globals
 use vars qw( $REweekday3 $REmonth3 );
@@ -856,7 +856,7 @@ so that consecutive call produces a new table.
 
 The table column headers can be can be changed by setting the field
 $obj->{ColLabel} to a format as used by the standard function
-strftime.  The default format is: ColLabel => "%A<br>%Y-%m-%d", which
+strftime.  The default format is: ColLabel => "%AE<lt>E<gt>%Y-%m-%d", which
 looks something like:
 
    Monday
